@@ -25,9 +25,10 @@ defined('MOODLE_INTERNAL') or die('Direct access to this script is forbidden.');
 
 class entities {
     /**
-     *
      * Prepares convert for inclusion into XML
+     *
      * @param string $value
+     * @return string
      */
     public static function safexml($value) {
         $result = htmlspecialchars(html_entity_decode($value, ENT_QUOTES, 'UTF-8'),
@@ -57,7 +58,7 @@ class entities {
             $result = mb_convert_encoding($content, 'UTF-8', $encoding);
         }
 
-        // See if we can strip off body tag and anything outside of it
+        // See if we can strip off body tag and anything outside of it.
         foreach (array('body', 'html') as $tagname) {
             $regex = str_replace('##', $tagname, "/<##[^>]*>(.+)<\/##>/is");
             if (preg_match($regex, $result, $matches)) {
@@ -68,24 +69,22 @@ class entities {
         return $result;
     }
 
-    public function load_xml_resource ($path_to_file) {
+    public function load_xml_resource($path_to_file) {
 
         $resource = new DOMDocument();
 
-        cc2moodle::log_action('Load the XML resource file: ' . $path_to_file);
+        cc2moodle::log_action('Load the XML resource file: '.$path_to_file);
 
         if (!$resource->load($path_to_file)) {
-            cc2moodle::log_action('Cannot load the XML resource file: ' . $path_to_file, true);
+            cc2moodle::log_action('Cannot load the XML resource file: ' . $path_to_file, false);
         }
 
         return $resource;
     }
 
-    public function update_sources ($html, $root_path = '') {
+    public function update_sources($html, $root_path = '') {
 
-        $document = new DOMDocument();
-
-        @$document->loadHTML($html);
+        $document = $this->load_html($html);
 
         $tags = array('img' => 'src' , 'a' => 'href');
 
@@ -108,18 +107,17 @@ class entities {
             }
         }
 
-        $html = $this->clear_doctype($document->saveHTML());
+        $html = $this->html_insidebody($document);
 
         return $html;
     }
 
-    public function full_path ($path, $dir_sep = DIRECTORY_SEPARATOR) {
+    public function full_path($path, $dir_sep = DIRECTORY_SEPARATOR) {
 
         $token = '$IMS-CC-FILEBASE$';
         $path = str_replace($token, '', $path);
 
         if (is_string($path) && ($path != '')) {
-            $dir_sep;
             $dot_dir = '.';
             $up_dir = '..';
             $length = strlen($path);
@@ -154,13 +152,11 @@ class entities {
         }
 
         return $result;
-
     }
 
-    public function include_titles ($html) {
+    public function include_titles($html) {
 
-        $document = new DOMDocument();
-        @$document->loadHTML($html);
+        $document = $this->load_html($html);
 
         $images = $document->getElementsByTagName('img');
 
@@ -180,18 +176,17 @@ class entities {
             $image->setAttribute('title', $title);
         }
 
-        $html = $this->clear_doctype($document->saveHTML());
+        $html = $this->html_insidebody($document);
 
         return $html;
     }
 
-    public function get_external_xml ($identifier) {
-
-        $response = '';
+    public function get_external_xml($identifier) {
 
         $xpath = cc2moodle::newx_path(cc2moodle::$manifest, cc2moodle::$namespaces);
 
-        $files = $xpath->query('/imscc:manifest/imscc:resources/imscc:resource[@identifier="' . $identifier . '"]/imscc:file/@href');
+        $files = $xpath->query('/imscc:manifest/imscc:resources/imscc:resource[@identifier="'.
+            $identifier.'"]/imscc:file/@href');
 
         if (empty($files)) {
             $response = '';
@@ -202,8 +197,8 @@ class entities {
         return $response;
     }
 
-    public function move_files ($files, $destination_folder) {
-        global $CFG;
+    public function move_files($files, $destination_folder) {
+        global $CFG, $OUTPUT;
 
         if (!empty($files)) {
 
@@ -225,14 +220,14 @@ class entities {
                 }
 
                 if (!$copy_success) {
-                    notify('WARNING: Cannot copy the file ' . $source . ' to ' . $destination);
+                    echo $OUTPUT->notification('WARNING: Cannot copy the file ' . $source . ' to ' . $destination);
                     cc2moodle::log_action('Cannot copy the file ' . $source . ' to ' . $destination, false);
                 }
             }
         }
     }
 
-    protected function get_all_files () {
+    protected function get_all_files() {
         global $CFG;
 
         $all_files = array();
@@ -245,7 +240,7 @@ class entities {
 
             if (!empty($files) && ($files->length > 0)) {
                 foreach ($files as $file) {
-                    //omit html files
+                    // Omit html files.
                     $ext = strtolower(pathinfo($file->nodeValue, PATHINFO_EXTENSION));
                     if (in_array($ext, array('html', 'htm', 'xhtml'))) {
                         continue;
@@ -256,7 +251,7 @@ class entities {
             unset($files);
         }
 
-        //are there any labels?
+        // Are there any labels?
         $xquery = "//imscc:item/imscc:item/imscc:item[imscc:title][not(@identifierref)]";
         $labels = $xpath->query($xquery);
         if (!empty($labels) && ($labels->length > 0)) {
@@ -268,7 +263,7 @@ class entities {
             if (!file_exists($dpath)) {
                 mkdir($dpath, $CFG->directorypermissions, true);
             }
-            //copy the folder.gif file
+            // Copy the folder.gif file.
             $folder_gif = "{$CFG->dirroot}/pix/i/files.gif";
             copy($folder_gif, $fpath);
             $all_files[] = $rfpath;
@@ -289,16 +284,39 @@ class entities {
 
     }
 
-    private function clear_doctype ($html) {
+    /**
+     * @param string $html
+     * @return DOMDocument
+     */
+    private function load_html($html) {
+        // Need to make sure that the html passed has charset meta tag.
+        $metatag = '<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />';
+        if (strpos($html, $metatag) === false) {
+            $html = '<html><head>'.$metatag.'</head><body>'.$html.'</body></html>';
+        }
 
-        return preg_replace('/^<!DOCTYPE.+?>/',
-                            '',
-                            str_replace(array('<html>' , '</html>' , '<body>' , '</body>'),
-                                        array('' , '' , '' , ''),
-                                        $html));
+        $document = new DOMDocument();
+        @$document->loadHTML($html);
+
+        return $document;
     }
 
-    public function generate_random_string ($length = 6) {
+    /**
+     * @param DOMDocument $domdocument
+     * @return string
+     */
+    private function html_insidebody($domdocument) {
+        $html = '';
+        $bodyitems = $domdocument->getElementsByTagName('body');
+        if ($bodyitems->length > 0) {
+            $body = $bodyitems->item(0);
+            $html = str_ireplace(array('<body>', '</body>'), '', $body->C14N());
+        }
+
+        return $html;
+    }
+
+    public function generate_random_string($length = 6) {
 
         $response = '';
         $source = 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ';
@@ -309,7 +327,6 @@ class entities {
             $source = str_split($source, 1);
 
             for ($i = 1; $i <= $length; $i++) {
-                mt_srand((double) microtime() * 1000000);
                 $num = mt_rand(1, count($source));
                 $response .= $source[$num - 1];
             }
@@ -318,7 +335,7 @@ class entities {
         return $response;
     }
 
-    public function truncate_text ($text, $max, $remove_html) {
+    public function truncate_text($text, $max, $remove_html) {
 
         if ($max > 10) {
             $text = substr($text, 0, ($max - 6)) . ' [...]';
