@@ -14,6 +14,19 @@
 // You should have received a copy of the GNU General Public License
 // along with Moodle.  If not, see <http://www.gnu.org/licenses/>.
 
+namespace core_files;
+
+use core_external\external_api;
+use core_files\external\delete\draft;
+use core_files\external\get\unused_draft;
+use core_files_external;
+
+defined('MOODLE_INTERNAL') || die();
+
+global $CFG;
+
+require_once($CFG->dirroot . '/webservice/tests/helpers.php');
+require_once($CFG->dirroot . '/files/externallib.php');
 
 /**
  * PHPunit tests for external files API.
@@ -24,25 +37,18 @@
  * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
  * @since Moodle 2.6
  */
-defined('MOODLE_INTERNAL') || die();
-
-global $CFG;
-
-require_once($CFG->dirroot . '/webservice/tests/helpers.php');
-require_once($CFG->dirroot . '/files/externallib.php');
-
-class core_files_externallib_testcase extends advanced_testcase {
+class externallib_test extends \advanced_testcase {
 
     /*
      * Test core_files_external::upload().
      */
 
-    public function test_upload() {
+    public function test_upload(): void {
         global $USER;
 
         $this->resetAfterTest();
         $this->setAdminUser();
-        $context = context_user::instance($USER->id);
+        $context = \context_user::instance($USER->id);
         $contextid = $context->id;
         $component = "user";
         $filearea = "draft";
@@ -103,12 +109,12 @@ class core_files_externallib_testcase extends advanced_testcase {
     /*
      * Make sure only user component is allowed in  core_files_external::upload().
      */
-    public function test_upload_param_component() {
+    public function test_upload_param_component(): void {
         global $USER;
 
         $this->resetAfterTest();
         $this->setAdminUser();
-        $context = context_user::instance($USER->id);
+        $context = \context_user::instance($USER->id);
         $contextid = $context->id;
         $component = "backup";
         $filearea = "draft";
@@ -128,12 +134,12 @@ class core_files_externallib_testcase extends advanced_testcase {
     /*
      * Make sure only draft areas are allowed in  core_files_external::upload().
      */
-    public function test_upload_param_area() {
+    public function test_upload_param_area(): void {
         global $USER;
 
         $this->resetAfterTest();
         $this->setAdminUser();
-        $context = context_user::instance($USER->id);
+        $context = \context_user::instance($USER->id);
         $contextid = $context->id;
         $component = "user";
         $filearea = "draft";
@@ -156,7 +162,7 @@ class core_files_externallib_testcase extends advanced_testcase {
     /**
      * Test getting a list of files with and without a context ID.
      */
-    public function test_get_files() {
+    public function test_get_files(): void {
         global $USER, $DB;
 
         $this->resetAfterTest();
@@ -167,7 +173,7 @@ class core_files_externallib_testcase extends advanced_testcase {
 
         // Create a course.
         $course = $this->getDataGenerator()->create_course();
-        $record = new stdClass();
+        $record = new \stdClass();
         $record->course = $course->id;
         $record->name = "Mod data upload test";
         $record->intro = "Some intro of some sort";
@@ -178,7 +184,7 @@ class core_files_externallib_testcase extends advanced_testcase {
         // Create a new field in the database activity.
         $field = data_get_field_new('file', $module);
         // Add more detail about the field.
-        $fielddetail = new stdClass();
+        $fielddetail = new \stdClass();
         $fielddetail->d = $module->id;
         $fielddetail->mode = 'add';
         $fielddetail->type = 'file';
@@ -200,8 +206,8 @@ class core_files_externallib_testcase extends advanced_testcase {
         // Insert the information about the file.
         $contentid = $DB->insert_record('data_content', $datacontent);
         // Required information for uploading a file.
-        $context = context_module::instance($module->cmid);
-        $usercontext = context_user::instance($USER->id);
+        $context = \context_module::instance($module->cmid);
+        $usercontext = \context_user::instance($USER->id);
         $component = 'mod_data';
         $filearea = 'content';
         $itemid = $contentid;
@@ -231,7 +237,7 @@ class core_files_externallib_testcase extends advanced_testcase {
         $testfilelisting = external_api::clean_returnvalue(core_files_external::get_files_returns(), $testfilelisting);
 
         // With the information that we have provided we should get an object exactly like the one below.
-        $coursecontext = context_course::instance($course->id);
+        $coursecontext = \context_course::instance($course->id);
         $testdata = array();
         $testdata['parents'] = array();
         $testdata['parents']['0'] = array('contextid' => 1,
@@ -245,7 +251,7 @@ class core_files_externallib_testcase extends advanced_testcase {
                                           'filearea' => null,
                                           'itemid' => null,
                                           'filepath' => null,
-                                          'filename' => 'Miscellaneous');
+                                          'filename' => get_string('defaultcategoryname'));
         $testdata['parents']['2'] = array('contextid' => $coursecontext->id,
                                           'component' => null,
                                           'filearea' => null,
@@ -297,7 +303,7 @@ class core_files_externallib_testcase extends advanced_testcase {
     /**
      * Test delete draft files
      */
-    public function test_delete_draft_files() {
+    public function test_delete_draft_files(): void {
         global $USER;
 
         $this->resetAfterTest();
@@ -305,7 +311,7 @@ class core_files_externallib_testcase extends advanced_testcase {
 
         // Add files to user draft area.
         $draftitemid = file_get_unused_draft_itemid();
-        $context = context_user::instance($USER->id);
+        $context = \context_user::instance($USER->id);
         $filerecordinline = array(
             'contextid' => $context->id,
             'component' => 'user',
@@ -338,8 +344,8 @@ class core_files_externallib_testcase extends advanced_testcase {
             ['filepath' => '/', 'filename' => 'faketxt.txt'],
             ['filepath' => '/fakefolder/', 'filename' => ''],
         ];
-        $paths = core_files\external\delete\draft::execute($draftitemid, $filestodelete);
-        $paths = external_api::clean_returnvalue(core_files\external\delete\draft::execute_returns(), $paths);
+        $paths = draft::execute($draftitemid, $filestodelete);
+        $paths = external_api::clean_returnvalue(draft::execute_returns(), $paths);
 
         // Check everything was deleted.
         $files = core_files_external::get_files($context->id, 'user', 'draft', $draftitemid, '/', '');
@@ -350,15 +356,15 @@ class core_files_externallib_testcase extends advanced_testcase {
     /**
      * Test get_unused_draft_itemid.
      */
-    public function test_get_unused_draft_itemid() {
+    public function test_get_unused_draft_itemid(): void {
         global $USER;
 
         $this->resetAfterTest();
         $this->setAdminUser();
 
         // Add files to user draft area.
-        $result = core_files\external\get\unused_draft::execute();
-        $result = external_api::clean_returnvalue(core_files\external\get\unused_draft::execute_returns(), $result);
+        $result = unused_draft::execute();
+        $result = external_api::clean_returnvalue(unused_draft::execute_returns(), $result);
 
         $filerecordinline = [
             'contextid' => $result['contextid'],
@@ -377,7 +383,7 @@ class core_files_externallib_testcase extends advanced_testcase {
         $filerecordinline['filename'] = 'fakeimage.png';
         $fs->create_file_from_string($filerecordinline, 'img...');
 
-        $context = context_user::instance($USER->id);
+        $context = \context_user::instance($USER->id);
         // Check two files were created (one file and one directory).
         $files = core_files_external::get_files($context->id, 'user', 'draft', $result['itemid'], '/', '');
         $files = external_api::clean_returnvalue(core_files_external::get_files_returns(), $files);
