@@ -21,7 +21,5 @@
  * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
  * @since      2.9
  */
-define(function() {
-    // This module exposes only the raw data from M.cfg;
-    return M.cfg;
-});
+// This module exposes only the raw data from M.cfg;
+export default M.cfg;
