@@ -172,9 +172,7 @@ class behat_filepicker extends behat_base {
         $this->perform_on_element('delete', $exception);
 
         // Yes, we are sure.
-        // Using xpath + click instead of pressButton as 'Ok' it is a common string.
-        $okbutton = $this->find('css', 'div.fp-dlg button.fp-dlg-butconfirm');
-        $okbutton->click();
+        $this->execute('behat_general::i_click_on_in_the', [get_string('yes'), 'button', get_string('confirm'), 'dialogue']);
     }
 
     /**
@@ -291,7 +289,6 @@ class behat_filepicker extends behat_base {
         }
 
         $selectfilebutton = $this->find_button(get_string('getfile', 'repository'));
-        $this->ensure_node_is_visible($selectfilebutton);
         $selectfilebutton->click();
 
         // We wait for all the JS to finish as it is performing an action.
@@ -299,7 +296,6 @@ class behat_filepicker extends behat_base {
 
         if ($overwriteaction !== false) {
             $overwritebutton = $this->find_button($overwriteaction);
-            $this->ensure_node_is_visible($overwritebutton);
             $overwritebutton->click();
 
             // We wait for all the JS to finish.
