@@ -85,6 +85,7 @@ define(
             TOGGLE: '.toggle-display,.dropdown-toggle',
             SECTIONLI: 'li.section',
             SECTIONACTIONMENU: '.section_action_menu',
+            SECTIONACTIONMENUTRIGGER: '.section-actions',
             SECTIONITEM: '[data-for="section_title"]',
             ADDSECTIONS: '.changenumsections [data-add-sections]',
             SECTIONBADGES: '[data-region="sectionbadges"]',
@@ -957,16 +958,16 @@ define(
                     }
                 });
 
-                // Add a handler for section show/hide actions.
-                $('body').on('click keypress', SELECTOR.SECTIONLI + ' ' +
-                            SELECTOR.SECTIONACTIONMENU + '[data-sectionid] ' +
+                // Add a handler for section action menu.
+                $('body').on('click keypress',
+                            SELECTOR.SECTIONACTIONMENUTRIGGER + '[data-sectionid] ' +
                             'a[data-action]', function(e) {
                     if (e.type === 'keypress' && e.keyCode !== 13) {
                         return;
                     }
                     var actionItem = $(this),
                         sectionElement = actionItem.closest(SELECTOR.SECTIONLI),
-                        sectionId = actionItem.closest(SELECTOR.SECTIONACTIONMENU).attr('data-sectionid');
+                        sectionId = actionItem.closest(SELECTOR.SECTIONACTIONMENUTRIGGER).attr('data-sectionid');
 
                     if (actionItem.attr('data-action') === 'permalink') {
                         e.preventDefault();
