@@ -117,9 +117,6 @@ class redis extends handler implements SessionHandlerInterface {
         }
 
         if (isset($CFG->session_redis_encrypt) && $CFG->session_redis_encrypt) {
-            if (!$this->clustermode) {
-                $this->host[0] = 'tls://' . $this->host[0];
-            }
             $this->sslopts = $CFG->session_redis_encrypt;
         }
 
@@ -228,7 +225,7 @@ class redis extends handler implements SessionHandlerInterface {
                     $port = 0;
                     $trimmedservers[] = $server;
                 } else {
-                    $port = 6379; // No Unix socket so set default port.
+                    $port = $this->port ?? 6379; // No Unix socket so set default port.
                     if (strpos($server, ':')) { // Check for custom port.
                         list($server, $port) = explode(':', $server);
                     }
@@ -237,6 +234,12 @@ class redis extends handler implements SessionHandlerInterface {
 
                 // We only need the first record for the single redis.
                 if (!$this->clustermode) {
+                    // Handle the case when the server is not a Unix domain socket.
+                    if ($port !== 0) {
+                        list($server, ) = explode(':', $trimmedservers[0]);
+                    } else {
+                        $server = $trimmedservers[0];
+                    }
                     break;
                 }
             }
@@ -266,9 +269,8 @@ class redis extends handler implements SessionHandlerInterface {
                         $this->auth, !empty($opts) ? $opts : null);
                 } else {
                     $delay = rand(100, 500);
-                    list($server, $port) = explode(':', $trimmedservers[0]);
                     $this->connection = new \Redis();
-                    $this->connection->connect($server, $this->port ?? $port, 1, null, $delay, 1, $opts);
+                    $this->connection->connect($server, $port, 1, null, $delay, 1, $opts);
                     if ($this->auth !== '' && !$this->connection->auth($this->auth)) {
                         throw new $exceptionclass('Unable to authenticate.');
                     }
@@ -296,7 +298,7 @@ class redis extends handler implements SessionHandlerInterface {
                 }
                 return true;
             } catch (RedisException | RedisClusterException $e) {
-                $redishost = $this->clustermode ? implode(',', $this->host) : $this->host[0].':'.$this->port ?? $port;
+                $redishost = $this->clustermode ? implode(',', $this->host) : $server. ':'. $port;
                 $logstring = "Failed to connect (try {$counter} out of " . self::MAX_RETRIES . ") to Redis ";
                 $logstring .= "at ". $redishost .", the error returned was: {$e->getMessage()}";
                 debugging($logstring);
