@@ -122,7 +122,8 @@ class mysqli_native_moodle_database_test extends \advanced_testcase {
         } catch (moodle_exception $e) {
             // ... or fail.
             // Unfortunately we cannot be sure with the error string.
-            $this->markTestIncomplete('SSL not supported?');
+            $this->markTestSkipped('MySQL server does not support SSL. Unable to complete the test.');
+            return;
         }
 
         try {
