@@ -25,14 +25,14 @@ namespace core;
  * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
  */
 class session_manager_test extends \advanced_testcase {
-    public function test_start() {
+    public function test_start(): void {
         $this->resetAfterTest();
         // Session must be started only once...
         \core\session\manager::start();
         $this->assertDebuggingCalled('Session was already started!', DEBUG_DEVELOPER);
     }
 
-    public function test_init_empty_session() {
+    public function test_init_empty_session(): void {
         global $SESSION, $USER;
         $this->resetAfterTest();
 
@@ -92,7 +92,7 @@ class session_manager_test extends \advanced_testcase {
         $this->assertSame($GLOBALS['USER'], $USER);
     }
 
-    public function test_set_user() {
+    public function test_set_user(): void {
         global $USER;
         $this->resetAfterTest();
 
@@ -113,7 +113,7 @@ class session_manager_test extends \advanced_testcase {
         $this->assertSame($GLOBALS['USER'], $USER);
     }
 
-    public function test_login_user() {
+    public function test_login_user(): void {
         global $USER;
         $this->resetAfterTest();
 
@@ -131,7 +131,7 @@ class session_manager_test extends \advanced_testcase {
         $this->assertSame($GLOBALS['USER'], $USER);
     }
 
-    public function test_terminate_current() {
+    public function test_terminate_current(): void {
         global $USER, $SESSION;
         $this->resetAfterTest();
 
@@ -150,7 +150,7 @@ class session_manager_test extends \advanced_testcase {
         $this->assertSame($GLOBALS['USER'], $USER);
     }
 
-    public function test_write_close() {
+    public function test_write_close(): void {
         global $USER;
         $this->resetAfterTest();
 
@@ -164,7 +164,7 @@ class session_manager_test extends \advanced_testcase {
         $this->assertSame($GLOBALS['USER'], $USER);
     }
 
-    public function test_session_exists() {
+    public function test_session_exists(): void {
         global $CFG, $DB;
         $this->resetAfterTest();
 
@@ -210,7 +210,7 @@ class session_manager_test extends \advanced_testcase {
         $this->assertTrue(\core\session\manager::session_exists($sid));
     }
 
-    public function test_touch_session() {
+    public function test_touch_session(): void {
         global $DB;
         $this->resetAfterTest();
 
@@ -233,7 +233,7 @@ class session_manager_test extends \advanced_testcase {
         $this->assertLessThanOrEqual(time(), $updated);
     }
 
-    public function test_kill_session() {
+    public function test_kill_session(): void {
         global $DB, $USER;
         $this->resetAfterTest();
 
@@ -265,7 +265,7 @@ class session_manager_test extends \advanced_testcase {
         $this->assertSame($userid, $USER->id);
     }
 
-    public function test_kill_user_sessions() {
+    public function test_kill_user_sessions(): void {
         global $DB, $USER;
         $this->resetAfterTest();
 
@@ -317,7 +317,7 @@ class session_manager_test extends \advanced_testcase {
         $this->assertEquals(1, $DB->count_records('sessions', array('userid' => $userid, 'sid' => md5('pokus5'))));
     }
 
-    public function test_apply_concurrent_login_limit() {
+    public function test_apply_concurrent_login_limit(): void {
         global $DB;
         $this->resetAfterTest();
 
@@ -440,7 +440,7 @@ class session_manager_test extends \advanced_testcase {
         $this->assertCount(8, $DB->get_records('sessions'));
     }
 
-    public function test_kill_all_sessions() {
+    public function test_kill_all_sessions(): void {
         global $DB, $USER;
         $this->resetAfterTest();
 
@@ -473,7 +473,7 @@ class session_manager_test extends \advanced_testcase {
         $this->assertSame(0, $USER->id);
     }
 
-    public function test_gc() {
+    public function test_gc(): void {
         global $CFG, $DB, $USER;
         $this->resetAfterTest();
 
@@ -546,7 +546,7 @@ class session_manager_test extends \advanced_testcase {
      * Test loginas.
      * @copyright  2103 Rajesh Taneja <rajesh@moodle.com>
      */
-    public function test_loginas() {
+    public function test_loginas(): void {
         global $USER, $SESSION;
         $this->resetAfterTest();
 
@@ -604,7 +604,7 @@ class session_manager_test extends \advanced_testcase {
         $newfullname = fullname($adminuser, true);
     }
 
-    public function test_is_loggedinas() {
+    public function test_is_loggedinas(): void {
         $this->resetAfterTest();
 
         $user1 = $this->getDataGenerator()->create_user();
@@ -618,7 +618,7 @@ class session_manager_test extends \advanced_testcase {
         $this->assertTrue(\core\session\manager::is_loggedinas());
     }
 
-    public function test_get_realuser() {
+    public function test_get_realuser(): void {
         $this->resetAfterTest();
 
         $user1 = $this->getDataGenerator()->create_user();
@@ -672,7 +672,7 @@ class session_manager_test extends \advanced_testcase {
     /**
      * Test to get recent session locks.
      */
-    public function test_get_recent_session_locks() {
+    public function test_get_recent_session_locks(): void {
         global $CFG;
 
         $this->resetAfterTest();
@@ -702,7 +702,7 @@ class session_manager_test extends \advanced_testcase {
     /**
      * Test to update recent session locks.
      */
-    public function test_update_recent_session_locks() {
+    public function test_update_recent_session_locks(): void {
         global $CFG;
 
         $this->resetAfterTest();
@@ -722,7 +722,7 @@ class session_manager_test extends \advanced_testcase {
     /**
      * Test to get session lock info.
      */
-    public function test_get_session_lock_info() {
+    public function test_get_session_lock_info(): void {
         global $PERF;
 
         $this->resetAfterTest();
@@ -816,7 +816,7 @@ class session_manager_test extends \advanced_testcase {
      * @param array $url Session lock page url.
      * @param array $time Session lock time.
      */
-    public function test_get_locked_page_at($url, $time) {
+    public function test_get_locked_page_at($url, $time): void {
         global $CFG, $SESSION;
 
         $this->resetAfterTest();
@@ -830,7 +830,7 @@ class session_manager_test extends \advanced_testcase {
     /**
      * Test cleanup recent session locks.
      */
-    public function test_cleanup_recent_session_locks() {
+    public function test_cleanup_recent_session_locks(): void {
         global $CFG, $SESSION;
 
         $this->resetAfterTest();
@@ -913,7 +913,7 @@ class session_manager_test extends \advanced_testcase {
      * @param array $b second value to compare to $a.
      * @param array $expected the expected difference.
      */
-    public function test_array_session_diff(array $a, array $b, array $expected) {
+    public function test_array_session_diff(array $a, array $b, array $expected): void {
         $class = new \ReflectionClass('\core\session\manager');
         $method = $class->getMethod('array_session_diff');
 
