@@ -46,7 +46,7 @@ class access_manager_test extends \advanced_testcase {
     /**
      * Test access_manager private property quizsettings is null.
      */
-    public function test_access_manager_quizsettings_null() {
+    public function test_access_manager_quizsettings_null(): void {
         $this->quiz = $this->create_test_quiz($this->course);
 
         $accessmanager = $this->get_access_manager();
@@ -62,7 +62,7 @@ class access_manager_test extends \advanced_testcase {
     /**
      * Test that SEB is not required.
      */
-    public function test_seb_required_false() {
+    public function test_seb_required_false(): void {
         $this->quiz = $this->create_test_quiz($this->course);
 
         $accessmanager = $this->get_access_manager();
@@ -72,7 +72,7 @@ class access_manager_test extends \advanced_testcase {
     /**
      * Test that SEB is required.
      */
-    public function test_seb_required_true() {
+    public function test_seb_required_true(): void {
         $this->quiz = $this->create_test_quiz($this->course, settings_provider::USE_SEB_CONFIG_MANUALLY);
 
         $accessmanager = $this->get_access_manager();
@@ -82,7 +82,7 @@ class access_manager_test extends \advanced_testcase {
     /**
      * Test that user has capability to bypass SEB check.
      */
-    public function test_user_can_bypass_seb_check() {
+    public function test_user_can_bypass_seb_check(): void {
         $this->quiz = $this->create_test_quiz($this->course, settings_provider::USE_SEB_CONFIG_MANUALLY);
 
         $user = $this->getDataGenerator()->create_user();
@@ -98,7 +98,7 @@ class access_manager_test extends \advanced_testcase {
     /**
      * Test that user has capability to bypass SEB check.
      */
-    public function test_admin_user_can_bypass_seb_check() {
+    public function test_admin_user_can_bypass_seb_check(): void {
         $this->quiz = $this->create_test_quiz($this->course, settings_provider::USE_SEB_CONFIG_MANUALLY);
 
         // Test normal user cannot bypass check.
@@ -116,7 +116,7 @@ class access_manager_test extends \advanced_testcase {
     /**
      * Test user does not have capability to bypass SEB check.
      */
-    public function test_user_cannot_bypass_seb_check() {
+    public function test_user_cannot_bypass_seb_check(): void {
         $this->quiz = $this->create_test_quiz($this->course, settings_provider::USE_SEB_CONFIG_MANUALLY);
 
         $user = $this->getDataGenerator()->create_user();
@@ -129,7 +129,7 @@ class access_manager_test extends \advanced_testcase {
     /**
      * Test we can detect SEB usage.
      */
-    public function test_is_using_seb() {
+    public function test_is_using_seb(): void {
         $this->quiz = $this->create_test_quiz($this->course, settings_provider::USE_SEB_CONFIG_MANUALLY);
 
         $accessmanager = $this->get_access_manager();
@@ -146,7 +146,7 @@ class access_manager_test extends \advanced_testcase {
     /**
      * Test that the quiz Config Key matches the incoming request header.
      */
-    public function test_access_keys_validate_with_config_key() {
+    public function test_access_keys_validate_with_config_key(): void {
         global $FULLME;
         $this->quiz = $this->create_test_quiz($this->course, settings_provider::USE_SEB_CONFIG_MANUALLY);
 
@@ -165,7 +165,7 @@ class access_manager_test extends \advanced_testcase {
     /**
      * Test that the quiz Config Key matches a provided config key with no incoming request header.
      */
-    public function test_access_keys_validate_with_provided_config_key() {
+    public function test_access_keys_validate_with_provided_config_key(): void {
         $this->quiz = $this->create_test_quiz($this->course, settings_provider::USE_SEB_CONFIG_MANUALLY);
         $url = 'https://www.example.com/moodle';
         $accessmanager = $this->get_access_manager();
@@ -179,7 +179,7 @@ class access_manager_test extends \advanced_testcase {
     /**
      * Test that the quiz Config Key does not match the incoming request header.
      */
-    public function test_access_keys_fail_to_validate_with_config_key() {
+    public function test_access_keys_fail_to_validate_with_config_key(): void {
         $this->quiz = $this->create_test_quiz($this->course, settings_provider::USE_SEB_CONFIG_MANUALLY);
         $accessmanager = $this->get_access_manager();
 
@@ -189,7 +189,7 @@ class access_manager_test extends \advanced_testcase {
     /**
      * Test that config key is not checked when using client configuration with SEB.
      */
-    public function test_config_key_not_checked_if_client_requirement_is_selected() {
+    public function test_config_key_not_checked_if_client_requirement_is_selected(): void {
         $this->quiz = $this->create_test_quiz($this->course, settings_provider::USE_SEB_CLIENT_CONFIG);
         $accessmanager = $this->get_access_manager();
         $this->assertFalse($accessmanager->should_validate_config_key());
@@ -198,7 +198,7 @@ class access_manager_test extends \advanced_testcase {
     /**
      * Test that if there are no browser exam keys for quiz, check is skipped.
      */
-    public function test_no_browser_exam_keys_cause_check_to_be_successful() {
+    public function test_no_browser_exam_keys_cause_check_to_be_successful(): void {
         $this->quiz = $this->create_test_quiz($this->course, settings_provider::USE_SEB_CLIENT_CONFIG);
 
         $settings = seb_quiz_settings::get_record(['quizid' => $this->quiz->id]);
@@ -212,7 +212,7 @@ class access_manager_test extends \advanced_testcase {
     /**
      * Test that access fails if there is no hash in header.
      */
-    public function test_access_keys_fail_if_browser_exam_key_header_does_not_exist() {
+    public function test_access_keys_fail_if_browser_exam_key_header_does_not_exist(): void {
         $this->quiz = $this->create_test_quiz($this->course, settings_provider::USE_SEB_CLIENT_CONFIG);
 
         $settings = seb_quiz_settings::get_record(['quizid' => $this->quiz->id]);
@@ -225,7 +225,7 @@ class access_manager_test extends \advanced_testcase {
     /**
      * Test that access fails if browser exam key doesn't match hash in header.
      */
-    public function test_access_keys_fail_if_browser_exam_key_header_does_not_match_provided_hash() {
+    public function test_access_keys_fail_if_browser_exam_key_header_does_not_match_provided_hash(): void {
         $this->quiz = $this->create_test_quiz($this->course, settings_provider::USE_SEB_CLIENT_CONFIG);
 
         $settings = seb_quiz_settings::get_record(['quizid' => $this->quiz->id]);
@@ -239,7 +239,7 @@ class access_manager_test extends \advanced_testcase {
     /**
      * Test that browser exam key matches hash in header.
      */
-    public function test_browser_exam_keys_match_header_hash() {
+    public function test_browser_exam_keys_match_header_hash(): void {
         global $FULLME;
 
         $this->quiz = $this->create_test_quiz($this->course, settings_provider::USE_SEB_CLIENT_CONFIG);
@@ -259,7 +259,7 @@ class access_manager_test extends \advanced_testcase {
     /**
      * Test that browser exam key matches a provided browser exam key.
      */
-    public function test_browser_exam_keys_match_provided_browser_exam_key() {
+    public function test_browser_exam_keys_match_provided_browser_exam_key(): void {
         $this->quiz = $this->create_test_quiz($this->course, settings_provider::USE_SEB_CLIENT_CONFIG);
         $url = 'https://www.example.com/moodle';
         $settings = seb_quiz_settings::get_record(['quizid' => $this->quiz->id]);
@@ -275,7 +275,7 @@ class access_manager_test extends \advanced_testcase {
     /**
      * Test can get received config key.
      */
-    public function test_get_received_config_key() {
+    public function test_get_received_config_key(): void {
         $this->quiz = $this->create_test_quiz($this->course, settings_provider::USE_SEB_CLIENT_CONFIG);
         $accessmanager = $this->get_access_manager();
 
@@ -301,7 +301,7 @@ class access_manager_test extends \advanced_testcase {
     /**
      * Test can correctly get type of SEB usage for the quiz.
      */
-    public function test_get_seb_use_type() {
+    public function test_get_seb_use_type(): void {
         // No SEB.
         $this->quiz = $this->create_test_quiz($this->course);
         $accessmanager = $this->get_access_manager();
@@ -360,7 +360,7 @@ class access_manager_test extends \advanced_testcase {
      *
      * @dataProvider should_validate_basic_header_data_provider
      */
-    public function test_should_validate_basic_header($type, $expected) {
+    public function test_should_validate_basic_header($type, $expected): void {
         $accessmanager = $this->getMockBuilder(seb_access_manager::class)
             ->disableOriginalConstructor()
             ->onlyMethods(['get_seb_use_type'])
@@ -394,7 +394,7 @@ class access_manager_test extends \advanced_testcase {
      *
      * @dataProvider should_validate_config_key_data_provider
      */
-    public function test_should_validate_config_key($type, $expected) {
+    public function test_should_validate_config_key($type, $expected): void {
         $accessmanager = $this->getMockBuilder(seb_access_manager::class)
             ->disableOriginalConstructor()
             ->onlyMethods(['get_seb_use_type'])
@@ -427,7 +427,7 @@ class access_manager_test extends \advanced_testcase {
      *
      * @dataProvider should_validate_browser_exam_key_data_provider
      */
-    public function test_should_validate_browser_exam_key($type, $expected) {
+    public function test_should_validate_browser_exam_key($type, $expected): void {
         $accessmanager = $this->getMockBuilder(seb_access_manager::class)
             ->disableOriginalConstructor()
             ->onlyMethods(['get_seb_use_type'])
@@ -440,7 +440,7 @@ class access_manager_test extends \advanced_testcase {
     /**
      * Test that access manager uses cached Config Key.
      */
-    public function test_access_manager_uses_cached_config_key() {
+    public function test_access_manager_uses_cached_config_key(): void {
         global $FULLME;
         $this->quiz = $this->create_test_quiz($this->course, settings_provider::USE_SEB_CONFIG_MANUALLY);
 
@@ -474,7 +474,7 @@ class access_manager_test extends \advanced_testcase {
     /**
      * Check that valid SEB config key is null if quiz doesn't have SEB settings.
      */
-    public function test_valid_config_key_is_null_if_no_settings() {
+    public function test_valid_config_key_is_null_if_no_settings(): void {
         $this->quiz = $this->create_test_quiz($this->course, settings_provider::USE_SEB_NO);
         $accessmanager = $this->get_access_manager();
 
@@ -486,7 +486,7 @@ class access_manager_test extends \advanced_testcase {
     /**
      * Test if config key should not be validated.
      */
-    public function test_if_config_key_should_not_be_validated() {
+    public function test_if_config_key_should_not_be_validated(): void {
         $this->quiz = $this->create_test_quiz($this->course, settings_provider::USE_SEB_NO);
         $accessmanager = $this->get_access_manager();
 
@@ -496,7 +496,7 @@ class access_manager_test extends \advanced_testcase {
     /**
      * Test if browser exam key should not be validated.
      */
-    public function test_if_browser_exam_key_should_not_be_validated() {
+    public function test_if_browser_exam_key_should_not_be_validated(): void {
         $this->quiz = $this->create_test_quiz($this->course, settings_provider::USE_SEB_CONFIG_MANUALLY);
         $accessmanager = $this->get_access_manager();
 
@@ -506,7 +506,7 @@ class access_manager_test extends \advanced_testcase {
     /**
      * Test that access is set correctly in Moodle session.
      */
-    public function test_set_session_access() {
+    public function test_set_session_access(): void {
         global $SESSION;
 
         $this->quiz = $this->create_test_quiz($this->course, settings_provider::USE_SEB_CLIENT_CONFIG);
@@ -522,7 +522,7 @@ class access_manager_test extends \advanced_testcase {
     /**
      * Test that access is set in Moodle session for only course module associated with access manager.
      */
-    public function test_session_access_set_for_specific_course_module() {
+    public function test_session_access_set_for_specific_course_module(): void {
         global $SESSION;
 
         $this->quiz = $this->create_test_quiz($this->course, settings_provider::USE_SEB_CLIENT_CONFIG);
@@ -539,7 +539,7 @@ class access_manager_test extends \advanced_testcase {
     /**
      * Test that access state can be retrieved from Moodle session.
      */
-    public function test_validate_session_access() {
+    public function test_validate_session_access(): void {
         global $SESSION;
 
         $this->quiz = $this->create_test_quiz($this->course, settings_provider::USE_SEB_CLIENT_CONFIG);
@@ -555,7 +555,7 @@ class access_manager_test extends \advanced_testcase {
     /**
      * Test that access can be cleared from Moodle session.
      */
-    public function test_clear_session_access() {
+    public function test_clear_session_access(): void {
         global $SESSION;
 
         $this->quiz = $this->create_test_quiz($this->course, settings_provider::USE_SEB_CLIENT_CONFIG);
@@ -571,7 +571,7 @@ class access_manager_test extends \advanced_testcase {
     /**
      * Test we can decide if need to redirect to SEB config link.
      */
-    public function test_should_redirect_to_seb_config_link() {
+    public function test_should_redirect_to_seb_config_link(): void {
         $this->quiz = $this->create_test_quiz($this->course, settings_provider::USE_SEB_CONFIG_MANUALLY);
         $accessmanager = $this->get_access_manager();
 
