@@ -41,6 +41,7 @@ require_once($CFG->dirroot . '/question/tests/privacy_helper.php');
  * @package    mod_quiz
  * @copyright  2018 Andrew Nicols <andrew@nicols.co.uk>
  * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
+ * @covers \mod_quiz\privacy\provider
  */
 class provider_test extends \core_privacy\tests\provider_testcase {
 
@@ -49,7 +50,7 @@ class provider_test extends \core_privacy\tests\provider_testcase {
     /**
      * Test that a user who has no data gets no contexts
      */
-    public function test_get_contexts_for_userid_no_data() {
+    public function test_get_contexts_for_userid_no_data(): void {
         global $USER;
         $this->resetAfterTest();
         $this->setAdminUser();
@@ -61,7 +62,7 @@ class provider_test extends \core_privacy\tests\provider_testcase {
     /**
      * Test for provider::get_contexts_for_userid() when there is no quiz attempt at all.
      */
-    public function test_get_contexts_for_userid_no_attempt_with_override() {
+    public function test_get_contexts_for_userid_no_attempt_with_override(): void {
         global $DB;
         $this->resetAfterTest(true);
 
@@ -91,7 +92,7 @@ class provider_test extends \core_privacy\tests\provider_testcase {
     /**
      * The export function should handle an empty contextlist properly.
      */
-    public function test_export_user_data_no_data() {
+    public function test_export_user_data_no_data(): void {
         global $USER;
         $this->resetAfterTest();
         $this->setAdminUser();
@@ -113,7 +114,7 @@ class provider_test extends \core_privacy\tests\provider_testcase {
     /**
      * The delete function should handle an empty contextlist properly.
      */
-    public function test_delete_data_for_user_no_data() {
+    public function test_delete_data_for_user_no_data(): void {
         global $USER;
         $this->resetAfterTest();
         $this->setAdminUser();
@@ -131,7 +132,7 @@ class provider_test extends \core_privacy\tests\provider_testcase {
     /**
      * Export + Delete quiz data for a user who has made a single attempt.
      */
-    public function test_user_with_data() {
+    public function test_user_with_data(): void {
         global $DB;
         $this->resetAfterTest(true);
 
@@ -220,7 +221,7 @@ class provider_test extends \core_privacy\tests\provider_testcase {
     /**
      * Export + Delete quiz data for a user who has made a single attempt.
      */
-    public function test_user_with_preview() {
+    public function test_user_with_preview(): void {
         global $DB;
         $this->resetAfterTest(true);
 
@@ -283,7 +284,7 @@ class provider_test extends \core_privacy\tests\provider_testcase {
     /**
      * Export + Delete quiz data for a user who has made a single attempt.
      */
-    public function test_delete_data_for_all_users_in_context() {
+    public function test_delete_data_for_all_users_in_context(): void {
         global $DB;
         $this->resetAfterTest(true);
 
@@ -338,7 +339,7 @@ class provider_test extends \core_privacy\tests\provider_testcase {
     /**
      * Export + Delete quiz data for a user who has made a single attempt.
      */
-    public function test_wrong_context() {
+    public function test_wrong_context(): void {
         global $DB;
         $this->resetAfterTest(true);
 
@@ -465,7 +466,7 @@ class provider_test extends \core_privacy\tests\provider_testcase {
     /**
      * Test for provider::get_users_in_context().
      */
-    public function test_get_users_in_context() {
+    public function test_get_users_in_context(): void {
         global $DB;
         $this->resetAfterTest(true);
 
@@ -501,7 +502,7 @@ class provider_test extends \core_privacy\tests\provider_testcase {
     /**
      * Test for provider::delete_data_for_users().
      */
-    public function test_delete_data_for_users() {
+    public function test_delete_data_for_users(): void {
         global $DB;
         $this->resetAfterTest(true);
 
@@ -534,7 +535,7 @@ class provider_test extends \core_privacy\tests\provider_testcase {
         // Delete the data for user1 and user3 in course1 and check it is removed.
         $quiz1context = $quiz1obj->get_context();
         $approveduserlist = new \core_privacy\local\request\approved_userlist($quiz1context, 'mod_quiz',
-                [$user1->id, $user3->id]);
+            [$user1->id, $user3->id]);
         provider::delete_data_for_users($approveduserlist);
 
         // Only the attempt of user2 should be remained in quiz1.
