@@ -178,7 +178,7 @@ class provider_test extends provider_testcase {
     /**
      * Test {@link \mod_workshop\privacy\provider::get_contexts_for_userid()} implementation.
      */
-    public function test_get_contexts_for_userid() {
+    public function test_get_contexts_for_userid(): void {
 
         $cm11 = get_coursemodule_from_instance('workshop', $this->workshop11->id);
         $cm12 = get_coursemodule_from_instance('workshop', $this->workshop12->id);
@@ -209,7 +209,7 @@ class provider_test extends provider_testcase {
     /**
      * Test {@link \mod_workshop\privacy\provider::get_users_in_context()} implementation.
      */
-    public function test_get_users_in_context() {
+    public function test_get_users_in_context(): void {
 
         $cm11 = get_coursemodule_from_instance('workshop', $this->workshop11->id);
         $cm12 = get_coursemodule_from_instance('workshop', $this->workshop12->id);
@@ -256,7 +256,7 @@ class provider_test extends provider_testcase {
     /**
      * Test {@link \mod_workshop\privacy\provider::export_user_data()} implementation.
      */
-    public function test_export_user_data_1() {
+    public function test_export_user_data_1(): void {
 
         $contextlist = new \core_privacy\local\request\approved_contextlist($this->student1, 'mod_workshop', [
             \context_module::instance($this->workshop11->cmid)->id,
@@ -308,7 +308,7 @@ class provider_test extends provider_testcase {
     /**
      * Test {@link \mod_workshop\privacy\provider::export_user_data()} implementation.
      */
-    public function test_export_user_data_2() {
+    public function test_export_user_data_2(): void {
 
         $contextlist = new \core_privacy\local\request\approved_contextlist($this->student2, 'mod_workshop', [
             \context_module::instance($this->workshop11->cmid)->id,
@@ -328,7 +328,7 @@ class provider_test extends provider_testcase {
     /**
      * Test {@link \mod_workshop\privacy\provider::delete_data_for_all_users_in_context()} implementation.
      */
-    public function test_delete_data_for_all_users_in_context() {
+    public function test_delete_data_for_all_users_in_context(): void {
         global $DB;
 
         $this->assertTrue($DB->record_exists('workshop_submissions', ['workshopid' => $this->workshop11->id]));
@@ -345,7 +345,7 @@ class provider_test extends provider_testcase {
     /**
      * Test {@link \mod_workshop\privacy\provider::delete_data_for_user()} implementation.
      */
-    public function test_delete_data_for_user() {
+    public function test_delete_data_for_user(): void {
         global $DB;
 
         $student1submissions = $DB->get_records('workshop_submissions', [
@@ -429,7 +429,7 @@ class provider_test extends provider_testcase {
     /**
      * Test {@link \mod_workshop\privacy\provider::delete_data_for_users()} implementation.
      */
-    public function test_delete_data_for_users() {
+    public function test_delete_data_for_users(): void {
         global $DB;
 
         // Student1 has submissions in two workshops.
